@@ -1,9 +1,9 @@
 penalty_poly <-
   function(x, m = 2, xmin = min(x), xmax = max(x), 
-           periodic = FALSE, rescale = FALSE){
+           periodic = FALSE, rescale = FALSE, bernoulli = TRUE){
     # Polynomial Smoothing Spline Penalty
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # Update: 2019-04-04
+    # Update: 2020-10-22
     
     # initializations
     m <- as.integer(m)
@@ -13,6 +13,7 @@ penalty_poly <-
     # get kernel function name
     kerns <- c("lin", "cub", "qui")
     fname <- paste0(kerns[m], "kern", 0)
+    if(!bernoulli) fname <- paste0(".", fname)
     
     # evaluate kernel function
     Q <- outer(X = x, Y = x, FUN = fname, periodic = periodic)
