@@ -2,7 +2,7 @@ summary.gsm <-
   function(object, ...){
     # summary method for class "gsm"
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # Updated: 2020-05-20
+    # Updated: 2020-10-22
     
     # convert binomial (if response is a factor)
     if(object$family$family == "binomial" && any(class(object$data[,1])[1] == c("factor", "ordered"))){
@@ -14,6 +14,7 @@ summary.gsm <-
     fitted.values <- object$family$linkinv(object$linear.predictors)
     weighted <- ifelse(any(colnames(object$data) == "(weights)"), TRUE, FALSE)
     wt <- if(weighted) object$data$'(weights)' else 1
+    wsqrt <- sqrt(wt)
     rsign <- sign(object$data[,1] - fitted.values)
     dev.resid <- rsign * sqrt(object$family$dev.resids(object$data[,1], fitted.values, wt))
     
@@ -46,10 +47,16 @@ summary.gsm <-
     p.coef <- object$coefficients[nullindx]
     p.ster <- sqrt(rowSums(object$cov.sqrt[nullindx,,drop=FALSE]^2))
     p.tval <- p.coef / p.ster
-    p.pval <- 2 * (1 - pnorm(abs(p.tval)))
+    if(object$family$family == "gaussian"){
+      p.pval <- 2 * (1 - pt(abs(p.tval), df = erdf))
+      p.names <- c("Estimate", "Std. Error", "t value", "Pr(>|t|)")
+    } else {
+      p.pval <- 2 * (1 - pnorm(abs(p.tval)))
+      p.names <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+    }
     p.table <- data.frame(p.coef, p.ster, p.tval, p.pval)
     rownames(p.table) <- names(p.coef)
-    colnames(p.table) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+    colnames(p.table) <- p.names
     
     # smooth term names
     s.coef <- object$coefficients[-nullindx]
@@ -61,37 +68,33 @@ summary.gsm <-
     
     # smooth term degrees of freedom and SS
     ss <- s.df <- rep(0, nterms)
+    mueta <- object$family$mu.eta(object$linear.predictors)
+    vsqrt <- as.numeric(sqrt(mueta^2/object$family$variance(fitted.values)))
     if(object$specs$tprk){
       
-      mueta <- object$family$mu.eta(object$linear.predictors)
-      vsqrt <- as.numeric(sqrt(mueta^2/object$family$variance(fitted.values)))
-      
       Xmats <- predict(object, combine = FALSE, design = TRUE)
-      Xmats$X$p <- vsqrt * Xmats$X$p
-      Xmats$X$s <- vsqrt * Xmats$X$s
+      Xmats$X$p <- wsqrt * vsqrt * Xmats$X$p
+      Xmats$X$s <- wsqrt * vsqrt * Xmats$X$s
       Xpsvd <- svd(Xmats$X$p, nv = 0)
       Xmats$X$s <- Xmats$X$s - Xpsvd$u %*% crossprod(Xpsvd$u, Xmats$X$s)
       
-      ss <- sum((psolve(Xmats$X$s %*% object$cov.sqrt[-nullindx,,drop=FALSE]) %*% (Xmats$X$s %*% s.coef))^2) * object$dispersion
+      ss <- sum((psolve(Xmats$X$s %*% object$cov.sqrt[-nullindx,,drop=FALSE]) %*% (Xmats$X$s %*% s.coef))^2)
       pis <- rep(0, nterms)
       for(i in 1:nterms){
         fitX <- predict(object, terms = object$terms[i],
                         combine = FALSE, design = TRUE)
-        fitX$X$s <- vsqrt * fitX$X$s - Xpsvd$u %*% crossprod(Xpsvd$u, vsqrt * fitX$X$s)
-        pis[i] <- sum((fitX$X$s %*% s.coef)^2)
+        fitX$X$s <- wsqrt * vsqrt * fitX$X$s - Xpsvd$u %*% crossprod(Xpsvd$u, wsqrt * vsqrt * fitX$X$s)
         s.df[i] <- sum(rowSums((fitX$X$s %*% object$cov.sqrt[-nullindx,,drop=FALSE])^2)) / object$dispersion
+        pis[i] <- sum((fitX$X$s %*% s.coef)^2)
       }
       pis <- pis / sum(pis)
       ss <- ss * pis
       
     } else {
       
-      mueta <- object$family$mu.eta(object$linear.predictors)
-      vsqrt <- as.numeric(sqrt(mueta^2/object$family$variance(fitted.values)))
-      
       Xmats <- predict(object, combine = FALSE, design = TRUE)
-      Xmats$X$p <- vsqrt * Xmats$X$p
-      Xmats$X$s <- vsqrt * Xmats$X$s
+      Xmats$X$p <- wsqrt * vsqrt * Xmats$X$p
+      Xmats$X$s <- wsqrt * vsqrt * Xmats$X$s
       Xpsvd <- svd(Xmats$X$p, nv = 0)
       Xmats$X$s <- Xmats$X$s - Xpsvd$u %*% crossprod(Xpsvd$u, Xmats$X$s)
       
@@ -100,18 +103,27 @@ summary.gsm <-
       for(i in 1:nterms){
         sindx <- which(snames == object$terms[i])
         X <- Xmats$X$s[,sindx,drop=FALSE]
-        ss[i] <- sum((psolve(X %*% object$cov.sqrt[nsdf + sindx,,drop=FALSE]) %*% (X %*% s.coef[sindx]))^2) * object$dispersion
         s.df[i] <- sum(rowSums((X %*% object$cov.sqrt[nsdf + sindx,,drop=FALSE])^2)) / object$dispersion
+        ss[i] <- sum((psolve(X %*% object$cov.sqrt[nsdf + sindx,,drop=FALSE]) %*% (X %*% s.coef[sindx]))^2)
       }
       
     } # end if(object$specs$tprk)
     
     # smooth coefficients table
-    s.Chisq <- pmax(ss, 0) / s.df
-    s.pvals <- 1 - pchisq(s.Chisq, df = s.df)
-    s.table <- rbind(cbind(s.df, ss, s.Chisq, s.pvals),
-                     c(erdf, object$deviance, NA, NA))
-    colnames(s.table) <- c("Df", "Sum Sq", "Chi Sq", "p.value")
+    fam.Ftest <- c("gaussian", "Gamma", "inverse.gaussian")
+    if(object$family$family %in% fam.Ftest){
+      ss <- ss * object$dispersion
+      s.Fstat <- (pmax(ss, 0) / s.df) / object$dispersion
+      s.pvals <- 1 - pf(s.Fstat, df1 = pmax(s.df, 1), df2 = erdf)
+      s.table <- rbind(cbind(s.df, ss, ss / s.df, s.Fstat, s.pvals),
+                       c(erdf, object$deviance, object$dispersion, NA, NA))
+      colnames(s.table) <- c("Df", "Sum Sq", "Mean Sq", "F value", "Pr(>F)")
+    } else {
+      s.pvals <- 1 - pchisq(ss, df = pmax(s.df, 1))
+      s.table <- rbind(cbind(s.df, ss, s.pvals),
+                       c(erdf, object$deviance, NA))
+      colnames(s.table) <- c("Df", "Chi Sq", "p.value")
+    }
     rownames(s.table) <- c(paste0("s(",object$terms, ")"), "Residuals")
     
     # overall F stat
@@ -132,7 +144,8 @@ summary.gsm <-
                 r.squared = object$r.squared,
                 adj.r.squared = as.numeric(adjRsq), 
                 kappa = kappa, pi = pi, 
-                call = object$call)
+                call = object$call,
+                family = object$family)
     class(res) <- "summary.gsm"
     return(res)
     
@@ -182,8 +195,9 @@ print.summary.gsm <-
     # smooth effect table
     cat("\nApprox. Signif. of Nonparametric Effects:\n")
     smoo <- as.data.frame(x$s.table)
+    fam.Ftest <- c("gaussian", "Gamma", "inverse.gaussian")
     if(signif.stars){
-      pstars <- symnum(x$s.table[,4],
+      pstars <- symnum(x$s.table[,ifelse(x$family$family %in% fam.Ftest, 5, 3)],
                        cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
                        symbols = c("***", "**", "*", ".", " "), na = NA)
       smoonames <- names(smoo)
